@@ -104,7 +104,7 @@ def enlarge(src, img):
 	if not src:
 		return None
 	src = src.replace('/m/', '/l/')
-	if 'animate' in img.parent.get('class'):
+	if 'animate' in img.parent.get('class', ''):
 		src = '.'.join(src.split('.')[:-1]) + '.mp4'
 	return src
 
@@ -145,6 +145,7 @@ def getContent(path, force_cache=False):
 	return cached_url.get(path, force_cache=force_cache)
 
 def get(path, force_cache=False):
+	path = path.replace('m.douban.com', 'www.douban.com')
 	content = getContent(path, force_cache=force_cache)
 	b = BeautifulSoup(content, features='lxml')
 	result = Result()
